==> openshift-model-config-6.0.0-sources.jar: io/fabric8/openshift/api/model/config/v1/AlibabaCloudPlatformStatusFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface AlibabaCloudPlatformStatusFluent<A extends AlibabaCloudPlatformStatusFluent<A>> extends Fluent<A>{
  public String getRegion();
  public A withRegion(String region);
  public Boolean hasRegion();
  public String getResourceGroupID();
  public A withResourceGroupID(String resourceGroupID);
  public Boolean hasResourceGroupID();
  public A addToResourceTags(Integer index,AlibabaCloudResourceTag item);
  public A setToResourceTags(Integer index,AlibabaCloudResourceTag item);
  public A addToResourceTags(io.fabric8.openshift.api.model.config.v1.AlibabaCloudResourceTag... items);
  public A addAllToResourceTags(Collection<AlibabaCloudResourceTag> items);
  public A removeFromResourceTags(io.fabric8.openshift.api.model.config.v1.AlibabaCloudResourceTag... items);
  public A removeAllFromResourceTags(Collection<AlibabaCloudResourceTag> items);
  public A removeMatchingFromResourceTags(Predicate<AlibabaCloudResourceTagBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildResourceTags instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<AlibabaCloudResourceTag> getResourceTags();
  public List<AlibabaCloudResourceTag> buildResourceTags();
  public AlibabaCloudResourceTag buildResourceTag(Integer index);
  public AlibabaCloudResourceTag buildFirstResourceTag();
  public AlibabaCloudResourceTag buildLastResourceTag();
  public AlibabaCloudResourceTag buildMatchingResourceTag(Predicate<AlibabaCloudResourceTagBuilder> predicate);
  public Boolean hasMatchingResourceTag(Predicate<AlibabaCloudResourceTagBuilder> predicate);
  public A withResourceTags(List<AlibabaCloudResourceTag> resourceTags);
  public A withResourceTags(io.fabric8.openshift.api.model.config.v1.AlibabaCloudResourceTag... resourceTags);
  public Boolean hasResourceTags();
  public A addNewResourceTag(String key,String value);
  public AlibabaCloudPlatformStatusFluent.ResourceTagsNested<A> addNewResourceTag();
  public AlibabaCloudPlatformStatusFluent.ResourceTagsNested<A> addNewResourceTagLike(AlibabaCloudResourceTag item);
  public AlibabaCloudPlatformStatusFluent.ResourceTagsNested<A> setNewResourceTagLike(Integer index,AlibabaCloudResourceTag item);
  public AlibabaCloudPlatformStatusFluent.ResourceTagsNested<A> editResourceTag(Integer index);
  public AlibabaCloudPlatformStatusFluent.ResourceTagsNested<A> editFirstResourceTag();
  public AlibabaCloudPlatformStatusFluent.ResourceTagsNested<A> editLastResourceTag();
  public AlibabaCloudPlatformStatusFluent.ResourceTagsNested<A> editMatchingResourceTag(Predicate<AlibabaCloudResourceTagBuilder> predicate);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ResourceTagsNested<N> extends Nested<N>,AlibabaCloudResourceTagFluent<AlibabaCloudPlatformStatusFluent.ResourceTagsNested<N>>{
    public N and();
    public N endResourceTag();
    
  }
  
}

==> openshift-model-config-6.7.2-sources.jar: io/fabric8/openshift/api/model/config/v1/AlibabaCloudPlatformStatusFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface AlibabaCloudPlatformStatusFluent<A extends AlibabaCloudPlatformStatusFluent<A>> extends Fluent<A>{
  public String getRegion();
  public A withRegion(String region);
  public Boolean hasRegion();
  public String getResourceGroupID();
  public A withResourceGroupID(String resourceGroupID);
  public Boolean hasResourceGroupID();
  public A addToResourceTags(int index,AlibabaCloudResourceTag item);
  public A setToResourceTags(int index,AlibabaCloudResourceTag item);
  public A addToResourceTags(io.fabric8.openshift.api.model.config.v1.AlibabaCloudResourceTag... items);
  public A addAllToResourceTags(Collection<AlibabaCloudResourceTag> items);
  public A removeFromResourceTags(io.fabric8.openshift.api.model.config.v1.AlibabaCloudResourceTag... items);
  public A removeAllFromResourceTags(Collection<AlibabaCloudResourceTag> items);
  public A removeMatchingFromResourceTags(Predicate<AlibabaCloudResourceTagBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildResourceTags instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<AlibabaCloudResourceTag> getResourceTags();
  public List<AlibabaCloudResourceTag> buildResourceTags();
  public AlibabaCloudResourceTag buildResourceTag(int index);
  public AlibabaCloudResourceTag buildFirstResourceTag();
  public AlibabaCloudResourceTag buildLastResourceTag();
  public AlibabaCloudResourceTag buildMatchingResourceTag(Predicate<AlibabaCloudResourceTagBuilder> predicate);
  public Boolean hasMatchingResourceTag(Predicate<AlibabaCloudResourceTagBuilder> predicate);
  public A withResourceTags(List<AlibabaCloudResourceTag> resourceTags);
  public A withResourceTags(io.fabric8.openshift.api.model.config.v1.AlibabaCloudResourceTag... resourceTags);
  public Boolean hasResourceTags();
  public A addNewResourceTag(String key,String value);
  public AlibabaCloudPlatformStatusFluent.ResourceTagsNested<A> addNewResourceTag();
  public AlibabaCloudPlatformStatusFluent.ResourceTagsNested<A> addNewResourceTagLike(AlibabaCloudResourceTag item);
  public AlibabaCloudPlatformStatusFluent.ResourceTagsNested<A> setNewResourceTagLike(int index,AlibabaCloudResourceTag item);
  public AlibabaCloudPlatformStatusFluent.ResourceTagsNested<A> editResourceTag(int index);
  public AlibabaCloudPlatformStatusFluent.ResourceTagsNested<A> editFirstResourceTag();
  public AlibabaCloudPlatformStatusFluent.ResourceTagsNested<A> editLastResourceTag();
  public AlibabaCloudPlatformStatusFluent.ResourceTagsNested<A> editMatchingResourceTag(Predicate<AlibabaCloudResourceTagBuilder> predicate);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ResourceTagsNested<N> extends Nested<N>,AlibabaCloudResourceTagFluent<AlibabaCloudPlatformStatusFluent.ResourceTagsNested<N>>{
    public N and();
    public N endResourceTag();
    
  }
  
}
